@@ -173,16 +173,23 @@ class Interval():
         if other.__class__.__name__ == "Interval":
 
             if other.straddles_zero():
-                # Cant divide by zero
-                raise ZeroDivisionError()
+                if other.Left == 0:
+                    lo = min(self.lo() / other.hi(), self.hi() / other.hi())
+                    hi = np.inf
+                elif other.Right == 0:
+                    lo = -np.inf
+                    hi = max(self.lo() / other.lo(), self.hi() / other.lo())
+                else:
+                    # Cant divide by zero
+                    raise ZeroDivisionError()
+            else:
+                b1 = self.lo() / other.lo()
+                b2 = self.lo() / other.hi()
+                b3 = self.hi() / other.lo()
+                b4 = self.hi() / other.hi()
 
-            b1 = self.lo() / other.lo()
-            b2 = self.lo() / other.hi()
-            b3 = self.hi() / other.lo()
-            b4 = self.hi() / other.hi()
-
-            lo = min(b1,b2,b3,b4)
-            hi = max(b1,b2,b3,b4)
+                lo = min(b1,b2,b3,b4)
+                hi = max(b1,b2,b3,b4)
 
         else:
             try:
@@ -267,6 +274,11 @@ class Interval():
                 return Logical(0,1)
             else:
                 return Logical(0,0)
+        elif other is None:
+            try:
+                self is None
+            except:
+                raise ValueError
         else:
             try:
                 if self.straddles(other):
@@ -313,7 +325,10 @@ class Interval():
                 else:
                     return Logical(1,1)
             except:
-                raise ValueError
+                try:
+                    return not self is other
+                except:
+                    raise ValueError
 
     def __le__(self,other):
         # <=
@@ -493,6 +508,24 @@ class Interval():
         else:
             return Interval(1/self.lo(), 1/self.hi())
 
+    def intersection(self, other):
+        if isinstance(other, Interval):
+            if self.straddles(other):
+                return I(max([x.Left for x in [self, other]]), min([x.Right for x in [self, other]]))
+            else:
+                return None
+        elif isinstance(other, list):
+            if all([self.straddles(o) for o in other]):
+                assert all([isinstance(o, Interval) for o in other]), 'All intersected objects must be intervals'
+                return I(max([x.Left for x in [self] + other]), min([x.Right for x in [self] + other]))
+            else:
+                return None
+        else:
+            if self.straddles(other):
+                return other
+            else:
+                return None
+
 
 # a = Interval(1,2)
 # b = Interval(3,4)
